@@ -44,7 +44,6 @@ set( 'SQL_INTERVAL_SELECT_BY_IID', q/
 set( 'SQL_INTERVAL_SELECT_BY_EID_AND_TSRANGE', q/
       SELECT i.iid, i.eid, i.aid, a.code, i.intvl, i.long_desc, i.remark
       FROM intervals i, activities a WHERE i.eid = ? AND i.intvl <@ ? AND i.aid = a.aid
-      ORDER BY intvl
       LIMIT ?
       / );
 
@@ -55,8 +54,6 @@ set( 'SQL_INTERVAL_SELECT_BY_EID_AND_TSRANGE_PARTIAL_INTERVALS', q/
       EXCEPT
       SELECT i.iid, i.eid, i.aid, a.code, i.intvl, i.long_desc, i.remark
       FROM intervals i, activities a WHERE i.eid = ? AND i.intvl <@ ? AND i.aid = a.aid
-      ORDER BY intvl
-      LIMIT ?
       / );
 
 #
@@ -67,7 +64,7 @@ set( 'SQL_INTERVAL_SELECT_COUNT_BY_EID_AND_TSRANGE', q/
 
 #
 set( 'SQL_INTERVAL_DELETE_BY_EID_AND_TSRANGE', q/
-      DELETE FROM intervals WHERE eid = ? AND intvl && ? 
+      DELETE FROM intervals WHERE eid = ? AND intvl <@ ? 
       / );
 
 #
