@@ -275,6 +275,14 @@ sub _vet_date_list {
     my @sorted_date_list = sort @canonicalized_date_list;
     $self->date_list( \@sorted_date_list );
 
+    my $noof_entries = scalar( @{ $self->date_list } );
+    if ( $noof_entries > $site->DOCHAZKA_INTERVAL_FILLUP_MAX_DATELIST_ENTRIES ) {
+        return $CELL->status_err( 
+            'DOCHAZKA_INTERVAL_FILLUP_DATELIST_TOO_LONG', 
+            args => [ $noof_entries ],
+        );
+    }
+
     # populate tsrange
     if ( scalar @sorted_date_list == 0 ) {
         $self->tsrange( undef );
@@ -378,33 +386,6 @@ sub _vet_tsrange {
 }
 
 
-=head2 _tsrange_long_enough
-
-This method checks the tsrange to find out if it's not too short. (The
-C<fillup_tempintvls> method has trouble with very short tsranges.)
-
-Returns a status object.
-
-=cut
-
-sub _tsrange_long_enough {
-    my $self = shift;
-    $log->debug( "Entering " . __PACKAGE__ . "::_tsrange_long_enough" );
-
-    my $hours = calculate_hours( $self->tsrange->{tsrange} );
-
-    die "HARDY_LAUREL_BOMB in _tsrange_long_enough tsrange not canonicalized"
-        if $hours == 0;
-
-    return $CELL->status_err( 
-        'DOCHAZKA_FILLUP_TSRANGE_TOO_SHORT', 
-        args => [ $hours ] 
-    ) if $hours < 24;
-
-    return $CELL->status_ok( 'SUCCESS', args => [ $hours ] );
-}
-
-
 =head2 _vet_employee
 
 Expects to be called *after* C<_vet_tsrange>.
@@ -659,8 +640,8 @@ sub new {
         },
         aid => { type => SCALAR|UNDEF, optional => 1 },
         code => { type => SCALAR|UNDEF, optional => 1 },
-        tsrange => { type => SCALAR|UNDEF, optional => 1 },
-        date_list => { type => SCALAR|UNDEF, optional => 1 },
+        tsrange => { type => SCALAR, optional => 1 },
+        date_list => { type => ARRAYREF, optional => 1 },
         long_desc => { type => SCALAR|UNDEF, optional => 1 },
         remark => { type => SCALAR|UNDEF, optional => 1 },
         clobber => { type => BOOLEAN, default => 0 },
@@ -690,7 +671,6 @@ sub new {
     return $self unless $self->constructor_status->ok;
     $self->constructor_status( $self->_vet_tsrange( %ARGS ) );
     return $self unless $self->constructor_status->ok;
-    $self->constructor_status( $self->_tsrange_long_enough() );
     $self->constructor_status( $self->_vet_employee( emp_obj => $ARGS{emp_obj} ) );
     return $self unless $self->constructor_status->ok;
     $self->constructor_status( $self->_vet_activity( aid => $ARGS{aid} ) );
