@@ -1859,9 +1859,15 @@ EOH
     'interval/fillup' =>
     {
         parent => '/',
-        handler => 'handler_noop',
-        acl_profile => 'passerby',
-        cli => 'interval',
+        handler => {
+            GET => 'handler_noop',
+            POST => 'handler_fillup',
+        },
+        acl_profile => {
+            GET => 'passerby',
+            POST => 'active',
+        },
+        cli => 'interval fillup',
         description => 'Parent for interval fillup resources',
         documentation => <<'EOH',
 =pod
@@ -1870,107 +1876,6 @@ Parent for interval fillup resources
 EOH
     },
 
-    # /interval/fillup/eid/:eid/:tsrange
-    'interval/fillup/eid/:eid/:tsrange' => 
-    {
-        parent => 'interval/fillup',
-        handler => {
-            GET => 'handler_interval_fillup_eid',
-            POST => 'handler_interval_fillup_eid',
-        },
-        acl_profile => 'active', 
-        cli => 'interval fillup eid $EID $TSRANGE',
-        validations => {
-            'eid' => 'Int',
-            'tsrange' => $tsrange_validation,
-        },
-        description => 'Return set of scheduled attendance intervals (tsranges) for the given employee over the given tsrange',
-        documentation => <<'EOH',
-=pod
-
-=over
-
-=item * GET
-
-Return set of scheduled attendance intervals (tsranges) for the given employee
-over the given tsrange. Does not add any attendance data to the database.
-
-=item * POST
-
-Post scheduled attendance intervals (tsranges) for the given employee
-over the given tsrange.
-
-=back
-EOH
-    },
-
-    # /interval/fillup/nick/:nick/:tsrange
-    'interval/fillup/nick/:nick/:tsrange' => 
-    {
-        parent => 'interval/fillup',
-        handler => {
-            GET => 'handler_interval_fillup_nick',
-            POST => 'handler_interval_fillup_nick',
-        },
-        acl_profile => 'active', 
-        cli => 'interval fillup nick $NICK $TSRANGE',
-        validations => {
-            'nick' => $term_validation,
-            'tsrange' => $tsrange_validation,
-        },
-        description => 'Return set of scheduled attendance intervals (tsranges) for the given employee over the given tsrange',
-        documentation => <<'EOH',
-=pod
-
-=over
-
-=item * GET
-
-Return set of scheduled attendance intervals (tsranges) for the given employee
-over the given tsrange. Does not add any attendance data to the database.
-
-=item * POST
-
-Post scheduled attendance intervals (tsranges) for the given employee
-over the given tsrange.
-
-=back
-EOH
-    },
-
-    # /interval/fillup/self/:tsrange
-    'interval/fillup/self/:tsrange' => 
-    {
-        parent => 'schedule',
-        handler => {
-            GET => 'handler_interval_fillup_self',
-            POST => 'handler_interval_fillup_self',
-        },
-        acl_profile => 'active', 
-        cli => 'interval fillup self $TSRANGE',
-        description => 'Return set of scheduled attendance intervals (tsranges) for the given employee over the given tsrange',
-        validations => {
-            'tsrange' => $tsrange_validation,
-        },
-        documentation => <<'EOH',
-=pod
-
-=over
-
-=item * GET
-
-Return set of scheduled attendance intervals (tsranges) for the given employee
-over the given tsrange. Does not add any attendance data to the database.
-
-=item * POST
-
-Post scheduled attendance intervals (tsranges) for the given employee
-over the given tsrange.
-
-=back
-EOH
-    },
-
     # /interval/iid
     'interval/iid' => 
     {
